@@ -72,7 +72,7 @@ function show_message()
 	echo -e "$title: $*"
 
 	if [ -z "$STEAMOS" ]; then
-		if ! "${STEAM_ZENITY}" "$style" --text="$*" 2>/dev/null; then
+		if ! "${STEAM_ZENITY}" "$style" --text="$*" --width=450 2>/dev/null; then
 			# Save the prompt in a temporary file because it can have newlines in it
 			tmpfile="$(mktemp || echo "/tmp/steam_message.txt")"
 			echo -e "$*" >"$tmpfile"
@@ -394,6 +394,31 @@ function check_shared_libraries()
 	fi
 }
 
+function check_requirements()
+{
+	check_requirements_bin="$(command -v steam-runtime-check-requirements)"
+	if [ -z "$check_requirements_bin" ]; then
+		echo "Can't find 'steam-runtime-check-requirements', continuing anyway"
+	else
+		message="$("$check_requirements_bin")"
+		status=$?
+		if (( $status == 71 )); then
+			if [ -z "$message" ]; then
+				message="Sorry, it seems like this computer does not meet the requirements to run Steam."
+			fi
+			show_message --error "$message"
+			exit $status
+		elif (( $status != 0 )); then
+			if [ -z "$message" ]; then
+				message="steam-runtime-check-requirements failed with an unexpected nonzero exit status. Trying to continue"
+			fi
+			echo $message
+		else
+			echo "Steam client's requirements are satisfied"
+		fi
+	fi
+}
+
 function ignore_signal()
 {
 	:
@@ -681,6 +706,9 @@ if [ -z "$STEAMOS" ]; then
 	check_shared_libraries
 fi
 
+# Check that the current system meets the requirements
+check_requirements
+
 # disable SDL1.2 DGA mouse because we can't easily support it in the overlay
 export SDL_VIDEO_X11_DGAMOUSE=0
 
